@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '1.12';
+our $VERSION = '1.13';
 
 use DateTime::Locale::Data;
 use DateTime::Locale::FromData;
@@ -362,7 +362,7 @@ DateTime::Locale - Localization support for DateTime.pm
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 SYNOPSIS
 
@@ -370,7 +370,7 @@ version 1.12
 
   my $loc = DateTime::Locale->load('en-GB');
 
-  print $loc->native_locale_name, "\n", $loc->datetime_format_long, "\n";
+  print $loc->native_name, "\n", $loc->datetime_format_long, "\n";
 
   # but mostly just things like ...
 
@@ -452,7 +452,7 @@ reference if called in a scalar context.
 
 Returns an unsorted list of the available locale names in their native
 language, or an array reference if called in a scalar context. All native
-names in UTF-8 characters as appropriate.
+names use UTF-8 as appropriate.
 
 =head1 CLDR DATA BUGS
 
@@ -517,7 +517,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Mohammad S Anwar
+=for stopwords Karen Etheridge Mohammad S Anwar Sergey Leschenko yasu47b
 
 =over 4
 
@@ -529,6 +529,14 @@ Karen Etheridge <ether@cpan.org>
 
 Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
+=item *
+
+Sergey Leschenko <Sergey.Leschenko@portaone.com>
+
+=item *
+
+yasu47b <nakayamayasuhiro1986@gmail.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
